@@ -121,6 +121,25 @@ class EditAlarm(tables.LinkAction):
         return True
 
 
+class GraphMetric(tables.LinkAction):
+    name = "graph_alarm"
+    verbose_name = _("Graph Metric")
+    icon = "dashboard"
+
+    def render(self):
+        self.attrs['target'] = 'newtab'
+        return super(self, GraphMetric).render()
+
+    def get_link_url(self, datum):
+        name = datum['expression_data']['metric_name']
+        self.attrs['target'] = '_blank'
+        return "/static/grafana/index.html#/dashboard/script/detail.js?token=%s&name=%s" % \
+               (self.table.request.user.token.id, name)
+
+    def allowed(self, request, datum=None):
+        return 'metric_name' in datum['expression_data']
+
+
 class DeleteAlarm(tables.DeleteAction):
     name = "delete_alarm"
     verbose_name = _("Delete Alarm")
@@ -165,7 +184,8 @@ class AlarmsTable(tables.DataTable):
     class Meta:
         name = "alarms"
         verbose_name = _("Alarms")
-        row_actions = (ShowAlarmHistory,
+        row_actions = (GraphMetric,
+                       ShowAlarmHistory,
                        EditAlarm,
                        DeleteAlarm,
                        )
